@@ -42,11 +42,10 @@ class FfmpegProcess:
             duration_secs = float(probe(filepath)["format"]["duration"])
         except Exception:
             can_get_duration = False
-            print(f"\nUnable to get the duration of {filepath}:\nTherefore, a progress bar will not be shown.")
         else:
             can_get_duration = False
 
-        print(f"Running {' '.join(self._ffmpeg_args)}...")
+        print(f"Running: {' '.join(self._ffmpeg_args)}")
 
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
@@ -55,14 +54,15 @@ class FfmpegProcess:
                 stderr=f,
             )
 
-        progress_bar = tqdm(
-            total=duration_secs,
-            unit="s",
-            dynamic_ncols=True
-        )
+        if can_get_duration:
+            progress_bar = tqdm(
+                total=duration_secs,
+                unit="s",
+                dynamic_ncols=True
+            )
 
-        progress_bar.clear()
-        previous_seconds_processed = 0
+            progress_bar.clear()
+            previous_seconds_processed = 0
 
         try:
             while self._process.poll() is None:
@@ -75,7 +75,7 @@ class FfmpegProcess:
                         progress_bar.update(seconds_increase)
                         previous_seconds_processed = seconds_processed
                 else:
-                    print(self._process.stderr.readline().decode().strip())
+                    print(self._process.stdout.readline().decode().strip())
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
